@@ -30,9 +30,9 @@ G_BEGIN_DECLS
 typedef enum {
 	ARV_DEBUG_LEVEL_NONE,
 	ARV_DEBUG_LEVEL_WARNING,
+	ARV_DEBUG_LEVEL_INFO,
 	ARV_DEBUG_LEVEL_DEBUG,
-	ARV_DEBUG_LEVEL_LOG,
-	ARV_DEBUG_LEVEL_VERBOSE_LOG,
+	ARV_DEBUG_LEVEL_TRACE,
 	ARV_DEBUG_LEVEL_N_ELEMENTS
 } ArvDebugLevel;
 
@@ -62,65 +62,65 @@ typedef enum {
 extern ArvDebugCategoryInfos arv_debug_category_infos[];
 
 #define arv_warning_dom(...)		arv_warning (ARV_DEBUG_CATEGORY_DOM, __VA_ARGS__)
-#define arv_debug_dom(...)	 	arv_debug (ARV_DEBUG_CATEGORY_DOM, __VA_ARGS__)
-#define arv_log_dom(...)		arv_log (ARV_DEBUG_CATEGORY_DOM, __VA_ARGS__)
+#define arv_info_dom(...)	 	arv_info (ARV_DEBUG_CATEGORY_DOM, __VA_ARGS__)
+#define arv_debug_dom(...)		arv_debug (ARV_DEBUG_CATEGORY_DOM, __VA_ARGS__)
 
 #define arv_warning_interface(...)	arv_warning (ARV_DEBUG_CATEGORY_INTERFACE, __VA_ARGS__)
-#define arv_debug_interface(...) 	arv_debug (ARV_DEBUG_CATEGORY_INTERFACE, __VA_ARGS__)
-#define arv_log_interface(...)		arv_log (ARV_DEBUG_CATEGORY_INTERFACE, __VA_ARGS__)
+#define arv_info_interface(...) 	arv_info (ARV_DEBUG_CATEGORY_INTERFACE, __VA_ARGS__)
+#define arv_debug_interface(...)	arv_debug (ARV_DEBUG_CATEGORY_INTERFACE, __VA_ARGS__)
 
 #define arv_warning_device(...)		arv_warning (ARV_DEBUG_CATEGORY_DEVICE, __VA_ARGS__)
-#define arv_debug_device(...) 		arv_debug (ARV_DEBUG_CATEGORY_DEVICE, __VA_ARGS__)
-#define arv_log_device(...)		arv_log (ARV_DEBUG_CATEGORY_DEVICE, __VA_ARGS__)
+#define arv_info_device(...) 		arv_info (ARV_DEBUG_CATEGORY_DEVICE, __VA_ARGS__)
+#define arv_debug_device(...)		arv_debug (ARV_DEBUG_CATEGORY_DEVICE, __VA_ARGS__)
 
 #define arv_warning_chunk(...)		arv_warning (ARV_DEBUG_CATEGORY_CHUNK, __VA_ARGS__)
-#define arv_debug_chunk(...) 		arv_debug (ARV_DEBUG_CATEGORY_CHUNK, __VA_ARGS__)
-#define arv_log_chunk(...)		arv_log (ARV_DEBUG_CATEGORY_CHUNK, __VA_ARGS__)
+#define arv_info_chunk(...) 		arv_info (ARV_DEBUG_CATEGORY_CHUNK, __VA_ARGS__)
+#define arv_debug_chunk(...)		arv_debug (ARV_DEBUG_CATEGORY_CHUNK, __VA_ARGS__)
 
 #define arv_warning_stream(...)		arv_warning (ARV_DEBUG_CATEGORY_STREAM, __VA_ARGS__)
-#define arv_debug_stream(...) 		arv_debug (ARV_DEBUG_CATEGORY_STREAM, __VA_ARGS__)
-#define arv_log_stream(...)		arv_log (ARV_DEBUG_CATEGORY_STREAM, __VA_ARGS__)
+#define arv_info_stream(...) 		arv_info (ARV_DEBUG_CATEGORY_STREAM, __VA_ARGS__)
+#define arv_debug_stream(...)		arv_debug (ARV_DEBUG_CATEGORY_STREAM, __VA_ARGS__)
 
 #define arv_warning_stream_thread(...)	arv_warning (ARV_DEBUG_CATEGORY_STREAM_THREAD, __VA_ARGS__)
-#define arv_debug_stream_thread(...) 	arv_debug (ARV_DEBUG_CATEGORY_STREAM_THREAD, __VA_ARGS__)
-#define arv_log_stream_thread(...)	arv_log (ARV_DEBUG_CATEGORY_STREAM_THREAD, __VA_ARGS__)
+#define arv_info_stream_thread(...) 	arv_info (ARV_DEBUG_CATEGORY_STREAM_THREAD, __VA_ARGS__)
+#define arv_debug_stream_thread(...)	arv_debug (ARV_DEBUG_CATEGORY_STREAM_THREAD, __VA_ARGS__)
 
 #define arv_warning_cp(...)		arv_warning (ARV_DEBUG_CATEGORY_CP, __VA_ARGS__)
-#define arv_debug_cp(...) 		arv_debug (ARV_DEBUG_CATEGORY_CP, __VA_ARGS__)
-#define arv_log_cp(...)			arv_log (ARV_DEBUG_CATEGORY_CP, __VA_ARGS__)
-#define arv_verbosely_log_cp(...)	arv_verbosely_log (ARV_DEBUG_CATEGORY_CP, __VA_ARGS__)
+#define arv_info_cp(...) 		arv_info (ARV_DEBUG_CATEGORY_CP, __VA_ARGS__)
+#define arv_debug_cp(...)		arv_debug (ARV_DEBUG_CATEGORY_CP, __VA_ARGS__)
+#define arv_trace_cp(...)		arv_trace (ARV_DEBUG_CATEGORY_CP, __VA_ARGS__)
 
 #define arv_warning_sp(...)		arv_warning (ARV_DEBUG_CATEGORY_SP, __VA_ARGS__)
-#define arv_debug_sp(...) 		arv_debug (ARV_DEBUG_CATEGORY_SP, __VA_ARGS__)
-#define arv_log_sp(...)			arv_log (ARV_DEBUG_CATEGORY_SP, __VA_ARGS__)
-#define arv_verbosely_log_sp(...)	arv_verbosely_log (ARV_DEBUG_CATEGORY_SP, __VA_ARGS__)
+#define arv_info_sp(...) 		arv_info (ARV_DEBUG_CATEGORY_SP, __VA_ARGS__)
+#define arv_debug_sp(...)		arv_debug (ARV_DEBUG_CATEGORY_SP, __VA_ARGS__)
+#define arv_trace_sp(...)		arv_trace (ARV_DEBUG_CATEGORY_SP, __VA_ARGS__)
 
 #define arv_warning_genicam(...)	arv_warning (ARV_DEBUG_CATEGORY_GENICAM, __VA_ARGS__)
-#define arv_debug_genicam(...) 		arv_debug (ARV_DEBUG_CATEGORY_GENICAM, __VA_ARGS__)
-#define arv_log_genicam(...)		arv_log (ARV_DEBUG_CATEGORY_GENICAM, __VA_ARGS__)
+#define arv_info_genicam(...) 		arv_info (ARV_DEBUG_CATEGORY_GENICAM, __VA_ARGS__)
+#define arv_debug_genicam(...)		arv_debug (ARV_DEBUG_CATEGORY_GENICAM, __VA_ARGS__)
 
 #define arv_warning_policies(...)	arv_warning (ARV_DEBUG_CATEGORY_POLICIES, __VA_ARGS__)
-#define arv_debug_policies(...) 	arv_debug (ARV_DEBUG_CATEGORY_POLICIES, __VA_ARGS__)
-#define arv_log_policies(...)		arv_log (ARV_DEBUG_CATEGORY_POLICIES, __VA_ARGS__)
+#define arv_info_policies(...) 		arv_info (ARV_DEBUG_CATEGORY_POLICIES, __VA_ARGS__)
+#define arv_debug_policies(...)		arv_debug (ARV_DEBUG_CATEGORY_POLICIES, __VA_ARGS__)
 
 #define arv_warning_evaluator(...)	arv_warning (ARV_DEBUG_CATEGORY_EVALUATOR, __VA_ARGS__)
-#define arv_debug_evaluator(...) 	arv_debug (ARV_DEBUG_CATEGORY_EVALUATOR, __VA_ARGS__)
-#define arv_log_evaluator(...)		arv_log (ARV_DEBUG_CATEGORY_EVALUATOR, __VA_ARGS__)
+#define arv_info_evaluator(...) 	arv_info (ARV_DEBUG_CATEGORY_EVALUATOR, __VA_ARGS__)
+#define arv_debug_evaluator(...)	arv_debug (ARV_DEBUG_CATEGORY_EVALUATOR, __VA_ARGS__)
 
 #define arv_warning_misc(...)		arv_warning (ARV_DEBUG_CATEGORY_MISC, __VA_ARGS__)
-#define arv_debug_misc(...) 		arv_debug (ARV_DEBUG_CATEGORY_MISC, __VA_ARGS__)
-#define arv_log_misc(...)		arv_log (ARV_DEBUG_CATEGORY_MISC, __VA_ARGS__)
+#define arv_info_misc(...) 		arv_info (ARV_DEBUG_CATEGORY_MISC, __VA_ARGS__)
+#define arv_debug_misc(...)		arv_debug (ARV_DEBUG_CATEGORY_MISC, __VA_ARGS__)
 
 #define arv_warning_viewer(...)		arv_warning (ARV_DEBUG_CATEGORY_VIEWER, __VA_ARGS__)
-#define arv_debug_viewer(...)	 	arv_debug (ARV_DEBUG_CATEGORY_VIEWER, __VA_ARGS__)
-#define arv_log_viewer(...)		arv_log (ARV_DEBUG_CATEGORY_VIEWER, __VA_ARGS__)
+#define arv_info_viewer(...)	 	arv_info (ARV_DEBUG_CATEGORY_VIEWER, __VA_ARGS__)
+#define arv_debug_viewer(...)		arv_debug (ARV_DEBUG_CATEGORY_VIEWER, __VA_ARGS__)
 
 gboolean	arv_debug_check			(ArvDebugCategory category, ArvDebugLevel level);
 
 void 		arv_warning 			(ArvDebugCategory category, const char *format, ...) G_GNUC_PRINTF (2,3);
+void 		arv_info 			(ArvDebugCategory category, const char *format, ...) G_GNUC_PRINTF (2,3);
 void 		arv_debug 			(ArvDebugCategory category, const char *format, ...) G_GNUC_PRINTF (2,3);
-void 		arv_log 			(ArvDebugCategory category, const char *format, ...) G_GNUC_PRINTF (2,3);
-void 		arv_verbosely_log		(ArvDebugCategory category, const char *format, ...) G_GNUC_PRINTF (2,3);
+void 		arv_trace			(ArvDebugCategory category, const char *format, ...) G_GNUC_PRINTF (2,3);
 
 void 		arv_debug_print_infos 		(void);
 
