@@ -20,6 +20,7 @@
  * Author: Emmanuel Pacaud <emmanuel@gnome.org>
  */
 
+#include <arvdebugprivate.h>
 #include <arv.h>
 #include <stdlib.h>
 #include <stdio.h>
@@ -48,8 +49,11 @@ static const GOptionEntry arv_option_entries[] =
 	        &arv_option_genicam_file, 	"XML Genicam file to use", "genicam_filename"},
 	{ "gvsp-lost-ratio",    'r', 0, G_OPTION_ARG_DOUBLE,
 	        &arv_option_gvsp_lost_ratio,	"GVSP lost packet ratio", "packet_per_thousand"},
-	{ "debug", 		'd', 0, G_OPTION_ARG_STRING,
-		&arv_option_debug_domains, 	NULL, "category[:level][,...]" },
+	{
+		"debug", 			'd', 0, G_OPTION_ARG_STRING,
+		&arv_option_debug_domains, 	NULL,
+		"{<category>[:<level>][,...]|help}"
+	},
 	{ NULL }
 };
 
@@ -85,7 +89,13 @@ main (int argc, char **argv)
 
 	g_option_context_free (context);
 
-	arv_debug_enable (arv_option_debug_domains);
+	if (!arv_debug_enable (arv_option_debug_domains)) {
+		if (g_strcmp0 (arv_option_debug_domains, "help") != 0)
+			printf ("Invalid debug selection\n");
+		else
+			arv_debug_print_infos ();
+		return EXIT_FAILURE;
+	}
 
 	gv_camera = arv_gv_fake_camera_new_full (arv_option_interface_name, arv_option_serial_number, arv_option_genicam_file);
 
