@@ -73,7 +73,7 @@ arv_fake_stream_thread (void *data)
 	ArvFakeStreamThreadData *thread_data = data;
 	ArvBuffer *buffer;
 
-	arv_log_stream_thread ("[FakeStream::thread] Start");
+	arv_debug_stream_thread ("[FakeStream::thread] Start");
 
 	if (thread_data->callback != NULL)
 		thread_data->callback (thread_data->callback_data, ARV_STREAM_CALLBACK_TYPE_INIT, NULL);
@@ -103,7 +103,7 @@ arv_fake_stream_thread (void *data)
 	if (thread_data->callback != NULL)
 		thread_data->callback (thread_data->callback_data, ARV_STREAM_CALLBACK_TYPE_EXIT, NULL);
 
-	arv_log_stream_thread ("[FakeStream::thread] Stop");
+	arv_debug_stream_thread ("[FakeStream::thread] Stop");
 
 	return NULL;
 }
