@@ -449,7 +449,7 @@ arv_gc_register_node_finalize (GObject *self)
 						      priv->n_cache_hits + priv->n_cache_misses,
 						      priv->n_cache_errors);
 			else
-				arv_log_policies ("%-15s: cache hit(s) = %3u / %-3u",
+				arv_debug_policies ("%-15s: cache hit(s) = %3u / %-3u",
 						  name,
 						  priv->n_cache_hits,
 						  priv->n_cache_hits + priv->n_cache_misses);
@@ -510,7 +510,7 @@ arv_gc_register_node_get (ArvGcRegister *gc_register, void *buffer, guint64 leng
 	} else
 		memcpy (buffer, cache, length);
 
-	arv_log_genicam ("[GcRegisterNode::get] 0x%" G_GINT64_MODIFIER "x,%" G_GUINT64_FORMAT, address, length);
+	arv_debug_genicam ("[GcRegisterNode::get] 0x%" G_GINT64_MODIFIER "x,%" G_GUINT64_FORMAT, address, length);
 }
 
 static void
@@ -547,7 +547,7 @@ arv_gc_register_node_set (ArvGcRegister *gc_register, const void *buffer, guint6
 		return;
 	}
 
-	arv_log_genicam ("[GcRegisterNode::set] 0x%" G_GINT64_MODIFIER "x,%" G_GUINT64_FORMAT, address, length);
+	arv_debug_genicam ("[GcRegisterNode::set] 0x%" G_GINT64_MODIFIER "x,%" G_GUINT64_FORMAT, address, length);
 }
 
 static guint64
@@ -614,9 +614,9 @@ _get_integer_value (ArvGcRegisterNode *gc_register_node,
 			msb = 8 * length - register_msb - 1;
 		}
 
-		arv_log_genicam ("[GcRegisterNode::_get_integer_value] reglsb = %d, regmsb, %d, lsb = %d, msb = %d",
+		arv_debug_genicam ("[GcRegisterNode::_get_integer_value] reglsb = %d, regmsb, %d, lsb = %d, msb = %d",
 				 register_lsb, register_msb, lsb, msb);
-		arv_log_genicam ("[GcRegisterNode::_get_integer_value] value = 0x%08" G_GINT64_MODIFIER "x", value);
+		arv_debug_genicam ("[GcRegisterNode::_get_integer_value] value = 0x%08" G_GINT64_MODIFIER "x", value);
 
 		if (msb - lsb < 63)
 			mask = ((((guint64) 1) << (msb - lsb + 1)) - 1) << lsb;
@@ -631,7 +631,7 @@ _get_integer_value (ArvGcRegisterNode *gc_register_node,
 			value |= G_MAXUINT64 ^ (mask >> lsb);
 		}
 
-		arv_log_genicam ("[GcRegisterNode::_get_integer_value] mask  = 0x%08" G_GINT64_MODIFIER "x", mask);
+		arv_debug_genicam ("[GcRegisterNode::_get_integer_value] mask  = 0x%08" G_GINT64_MODIFIER "x", mask);
 	} else {
 		if (length < 8 &&
 		    ((value & (((guint64) 1) << (length * 8 - 1))) != 0) &&
@@ -639,7 +639,7 @@ _get_integer_value (ArvGcRegisterNode *gc_register_node,
 			value |= G_MAXUINT64 ^ ((((guint64) 1) << (length * 8)) - 1);
 	}
 
-	arv_log_genicam ("[GcRegisterNode::_get_integer_value] address = 0x%" G_GINT64_MODIFIER "x, value = 0x%" G_GINT64_MODIFIER "x",
+	arv_debug_genicam ("[GcRegisterNode::_get_integer_value] address = 0x%" G_GINT64_MODIFIER "x, value = 0x%" G_GINT64_MODIFIER "x",
 			 _get_address (gc_register_node, NULL), value);
 
 	return value;
@@ -707,9 +707,9 @@ _set_integer_value (ArvGcRegisterNode *gc_register_node,
 			msb = 8 * length - register_msb - 1;
 		}
 
-		arv_log_genicam ("[GcRegisterNode::_set_integer_value] reglsb = %d, regmsb, %d, lsb = %d, msb = %d",
+		arv_debug_genicam ("[GcRegisterNode::_set_integer_value] reglsb = %d, regmsb, %d, lsb = %d, msb = %d",
 				 register_lsb, register_msb, lsb, msb);
-		arv_log_genicam ("[GcRegisterNode::_set_integer_value] value = 0x%08" G_GINT64_MODIFIER "x", value);
+		arv_debug_genicam ("[GcRegisterNode::_set_integer_value] value = 0x%08" G_GINT64_MODIFIER "x", value);
 
 		if (msb - lsb < 63)
 			mask = ((((guint64) 1) << (msb - lsb + 1)) - 1) << lsb;
@@ -718,10 +718,10 @@ _set_integer_value (ArvGcRegisterNode *gc_register_node,
 
 		value = ((value << lsb) & mask) | (current_value & ~mask);
 
-		arv_log_genicam ("[GcRegisterNode::_set_integer_value] mask  = 0x%08" G_GINT64_MODIFIER "x", mask);
+		arv_debug_genicam ("[GcRegisterNode::_set_integer_value] mask  = 0x%08" G_GINT64_MODIFIER "x", mask);
 	}
 
-	arv_log_genicam ("[GcRegisterNode::_set_integer_value] address = 0x%" G_GINT64_MODIFIER "x, value = 0x%" G_GINT64_MODIFIER "x",
+	arv_debug_genicam ("[GcRegisterNode::_set_integer_value] address = 0x%" G_GINT64_MODIFIER "x, value = 0x%" G_GINT64_MODIFIER "x",
 			 _get_address (gc_register_node, NULL), value);
 
 	arv_copy_memory_with_endianness (cache, length, endianness,
